{interactive slug="binary-cards" type="whole-page" parameters="digits=5&start=BBBBB" thumbnail="binarycards.png" text="true"}

All of this silence and patience, pining and desperately waiting

{interactive end}

My hands are shaking from holding back from all this
